############# We load a WT vs mutant DESeq differential expression file
############# here Aire vs Aire-KO mTEChi

dat<-read.csv(file="WT_AireKO_counts_UCSCmm9_DESEQ.csv",header=TRUE)

dat<-dat[!is.na(dat$pval),]


############# We select a FC threshold to define the Aire-sensitive genes
############# here FC > 3

fc<-3

dat_plus<-dat[dat$foldChange>=fc,]


############# We select a FC threshold to define an equal number of Aire-neutral genes
############# here 1/1.06 < FC < 1.06 

fc_sup<-1.06
fc_inf<-1/fc_sup

dat_ctr<-dat[dat$foldChange>=fc_inf & dat$foldChange<=fc_sup,]


############# We load the read-count file generated by counting the reads mapping the features of the GFF2_features_mm9_UTR_d.gtf annotation file (provided in Figure 1-source data 1)

dat2<-read.csv(file="WT_AireKO_counts_UTRd.csv",header=TRUE)


feat_main<-"3UTRd"
feat_sec<-"3UTR"

dat_feat<-dat2[dat2$feature==feat_main | dat2$feature==feat_sec,]


#########
expSAUVAGE<-dat_feat$SAUVAGE/dat_feat$length
expMUTANT<-dat_feat$MUTANT/dat_feat$length
dat_feat<-data.frame(dat_feat,expSAUVAGE,expMUTANT)
#########


SELECTION_SAUVAGE_trans<-dat_feat[dat_feat$feature==feat_main,"SAUVAGE"]
SELECTION_MUTANT_trans<-dat_feat[dat_feat$feature==feat_main,"MUTANT"]

SELECTION_NM<-unique(dat_feat[,1])
SELECTION_trans<-data.frame(SELECTION_NM,SELECTION_SAUVAGE_trans,SELECTION_MUTANT_trans)

NM_SAUVAGE<-na.omit(SELECTION_trans[SELECTION_trans[,2]>=0 | SELECTION_trans[,3]>=0,1])
NM_MUTANT<-NM_SAUVAGE


ratio_SAUVAGE_trans<-dat_feat[dat_feat$feature==feat_main,"expSAUVAGE"]/dat_feat[dat_feat$feature==feat_sec,"expSAUVAGE"]
ratio_MUTANT_trans<-dat_feat[dat_feat$feature==feat_main,"expMUTANT"]/dat_feat[dat_feat$feature==feat_sec,"expMUTANT"]


NM<-unique(dat_feat[,1])
trans<-data.frame(NM,ratio_SAUVAGE_trans,ratio_MUTANT_trans)

ratio_SAUVAGE<-trans[match(dat_feat[,1],trans$NM),"ratio_SAUVAGE_trans"]
ratio_MUTANT<-trans[match(dat_feat[,1],trans$NM),"ratio_MUTANT_trans"]
dat_feat<-data.frame(dat_feat,ratio_SAUVAGE,ratio_MUTANT)


############# We combine the selections

plus_partiel<-dat_feat[match(dat_plus$id,dat_feat[,1]),]
plus<-data.frame(dat_plus,plus_partiel)

ctr_partiel<-dat_feat[match(dat_ctr$id,dat_feat[,1]),]
ctr<-data.frame(dat_ctr,ctr_partiel)

plus$ratio_SAUVAGE[plus$ratio_SAUVAGE=="Inf"]<-NA
plus$ratio_MUTANT[plus$ratio_MUTANT=="Inf"]<-NA

ctr$ratio_SAUVAGE[ctr$ratio_SAUVAGE=="Inf"]<-NA
ctr$ratio_MUTANT[ctr$ratio_MUTANT=="Inf"]<-NA


#############  Plot WT
#############  here we enter the number of reads of the WT sample (WT Aire) that map to the mm9 genome after Bowtie alignment
#############  here the number is 114828554

Nsauvage<-114828554



ctr2<-ctr[match(NM_SAUVAGE,ctr$id),]
Ctr_comb<-na.omit(cbind(ctr2$expSAUVAGE,ctr2$ratio_SAUVAGE))


XSctr<-log10(Ctr_comb[,1]*1000000000/Nsauvage)
XSctr1<-(Ctr_comb[,1]*1000000000/Nsauvage)
YSctr<-asinh(Ctr_comb[,2])
YSctr1<-(Ctr_comb[,2])


plus2<-plus[match(NM_SAUVAGE,plus$id),]


Plus_comb<-na.omit(data.frame(plus2$expSAUVAGE,plus2$ratio_SAUVAGE))

Plus_comb1<-na.omit(data.frame(plus2$id,plus2$expSAUVAGE,plus2$ratio_SAUVAGE))

XSplus<-log10(Plus_comb[,1]*1000000000/Nsauvage)
XSplus1<-(Plus_comb[,1]*1000000000/Nsauvage)
YSplus<-asinh(Plus_comb[,2])
YSplus1<-(Plus_comb[,2])


quartz()
library("ggplot2")
library(scales)
asinh_trans <- function(){
  trans_new(name = 'asinh', transform = function(x) asinh(x), 
            inverse = function(x) sinh(x))
}

dens1<-(YSplus1)
dens2<-(YSctr1)
value<-c(dens1,dens2)
variable<-c(rep("A",length(dens1)),rep("B",length(dens2)))
mydata<-cbind.data.frame(value,variable)


ggplot(mydata,aes(x=value,fill=variable,group=variable))+geom_density(aes(linetype=factor(variable)),size=0.8,alpha=0.7)+ylim(0,2.5)+scale_fill_manual( values = c("red","gray70"))+ scale_linetype_manual(values=c("blank","dashed"))+theme_bw()+labs(x="d3'UTR relative expression",y="density")+scale_x_continuous(trans = 'asinh',breaks=c(0,0.5,1,1.5,2),limits=c(0,2))


#############  Plot Mutant (Aire-KO)
#############  here we enter the number of reads of the Mutant sample (Aire-KO) that map to the mm9 genome after Bowtie
#############  here the number is 179098324

Nmutant<-179098324



ctr2<-ctr[match(NM_MUTANT,ctr$id),]
Ctr_comb<-na.omit(cbind(ctr2$expMUTANT,ctr2$ratio_MUTANT))


XSctr<-log10(Ctr_comb[,1]*1000000000/Nmutant)
XSctr1<-(Ctr_comb[,1]*1000000000/Nmutant)
YSctr<-asinh(Ctr_comb[,2])
YSctr1<-(Ctr_comb[,2])


plus2<-plus[match(NM_MUTANT,plus$id),]


Plus_comb<-na.omit(cbind(plus2$expMUTANT,plus2$ratio_MUTANT))

Plus_comb2<-na.omit(data.frame(plus2$id,plus2$expMUTANT,plus2$ratio_MUTANT))

XSplus<-log10(Plus_comb[,1]*1000000000/Nmutant)
XSplus1<-Plus_comb[,1]*1000000000/Nmutant
YSplus<-asinh(Plus_comb[,2])
YSplus1<-(Plus_comb[,2])


quartz()
library("ggplot2")
library(scales)
asinh_trans <- function(){
  trans_new(name = 'asinh', transform = function(x) asinh(x), 
            inverse = function(x) sinh(x))
}

dens1<-YSplus1
#dens2<-sample(YSctr,length(YSplus))
dens2<-YSctr1
value<-c(dens1,dens2)
variable<-c(rep("A",length(dens1)),rep("B",length(dens2)))
mydata<-cbind.data.frame(value,variable)

ggplot(mydata,aes(x=value,fill=variable,group=variable))+geom_density(aes(linetype=factor(variable)),size=0.8,alpha=0.7)+ylim(0,2.5)+scale_fill_manual( values = c("red","darkgray"))+ scale_linetype_manual(values=c("blank","dashed"))+theme_bw()+labs(x="d3'UTR relative expression",y="density")+scale_x_continuous(trans = 'asinh',breaks=c(0,0.5,1,1.5,2),limits=c(0,2))
